package com.dcsoft.system.face.mapper;

import com.dcsoft.system.face.domain.FaceRecord;

import java.util.List;

/**
 * 评分核验记录Mapper接口
 *
 * @author 倪春
 * @date 2023-04-21
 */
public interface FaceRecordMapper
{
    /**
     * 查询评分核验记录
     *
     * @param id 评分核验记录主键
     * @return 评分核验记录
     */
    public FaceRecord selectFaceRecordById(Long id);

    /**
     * 查询评分核验记录列表
     *
     * @param faceRecord 评分核验记录
     * @return 评分核验记录集合
     */
    public List<FaceRecord> selectFaceRecordList(FaceRecord faceRecord);

    /**
     * 新增评分核验记录
     *
     * @param faceRecord 评分核验记录
     * @return 结果
     */
    public int insertFaceRecord(FaceRecord faceRecord);

    /**
     * 修改评分核验记录
     *
     * @param faceRecord 评分核验记录
     * @return 结果
     */
    public int updateFaceRecord(FaceRecord faceRecord);

    /**
     * 删除评分核验记录
     *
     * @param id 评分核验记录主键
     * @return 结果
     */
    public int deleteFaceRecordById(Long id);

    /**
     * 批量删除评分核验记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteFaceRecordByIds(Long[] ids);
}
