package com.dcsoft.system.face.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.dcsoft.system.face.domain.FaceRecord;
import com.dcsoft.system.face.service.IFaceRecordService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.dcsoft.common.log.annotation.Log;
import com.dcsoft.common.log.enums.BusinessType;
import com.dcsoft.common.security.annotation.RequiresPermissions;
import com.dcsoft.common.core.web.controller.BaseController;
import com.dcsoft.common.core.web.domain.AjaxResult;
import com.dcsoft.common.core.utils.poi.ExcelUtil;
import com.dcsoft.common.core.web.page.TableDataInfo;

/**
 * 评分核验记录Controller
 *
 * @author 倪春
 * @date 2023-04-21
 */
@RestController
@RequestMapping("/faceRecord")
public class FaceRecordController extends BaseController
{
    @Autowired
    private IFaceRecordService faceRecordService;

    /**
     * 查询评分核验记录列表
     */
    @RequiresPermissions("face:record:list")
    @GetMapping("/list")
    public TableDataInfo list(FaceRecord faceRecord)
    {
        startPage();
        List<FaceRecord> list = faceRecordService.selectFaceRecordList(faceRecord);
        return getDataTable(list);
    }

    /**
     * 导出评分核验记录列表
     */
    @RequiresPermissions("face:record:export")
    @Log(title = "评分核验记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FaceRecord faceRecord)
    {
        List<FaceRecord> list = faceRecordService.selectFaceRecordList(faceRecord);
        ExcelUtil<FaceRecord> util = new ExcelUtil<FaceRecord>(FaceRecord.class);
        util.exportExcel(response, list, "评分核验记录数据");
    }

    /**
     * 获取评分核验记录详细信息
     */
    @RequiresPermissions("face:record:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(faceRecordService.selectFaceRecordById(id));
    }

    /**
     * 新增评分核验记录
     */
    @Log(title = "评分核验记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FaceRecord faceRecord)
    {
        return toAjax(faceRecordService.insertFaceRecord(faceRecord));
    }

    /**
     * 修改评分核验记录
     */
    @Log(title = "评分核验记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FaceRecord faceRecord)
    {
        return toAjax(faceRecordService.updateFaceRecord(faceRecord));
    }

    /**
     * 删除评分核验记录
     */
    @Log(title = "评分核验记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(faceRecordService.deleteFaceRecordByIds(ids));
    }
}
